import { LRLanguage, LanguageSupport } from "@codemirror/language";
import { ViewPlugin, ViewUpdate, DecorationSet } from "@codemirror/view";
import { Diagnostic } from "@codemirror/lint";
declare const NuformulaLanguage: LRLanguage;
declare function nuformula(): LanguageSupport;
type ItemOption = {
    label: string;
    [key: string]: any;
};
type Item = {
    sn: string;
    type: string;
    options: ItemOption;
    [key: string]: any;
};
declare const isEmptyValue: (value: any) => boolean;
declare enum funcName {
    SUM = "SUM",
    AVERAGE = "AVERAGE",
    IF = "IF",
    CONCAT = "CONCAT"
}
/**
 * 輸出 表單元件 decoration 插件
 *
 * @param {object} formItems - 所有表單元件
 * @returns {ViewPlugin}
 */
declare function nuformulaItemWidget(formItems: {
    [key: string]: Item;
}): ViewPlugin<{
    decorations: DecorationSet;
    update(update: ViewUpdate): void;
}>;
declare class NuLinter {
    text: string; // -------------------- 公式字串
    private length; // ---------- 公式字串長度
    private prevChar; // -------- 前一字符
    private char; // ------------ 當前字符
    private nextChar; // -------- 後一字符
    private pStack; // -------- 括號配對佇列
    private qStack; // -------- 引號配對佇列
    private iStack; // -------- 表單項目配對佇列
    private fStack; // ------- 函式參數佇列
    private itemSn; // ---------- 表單元件項目
    private funcName; // -------- 函式名稱
    constructor();
    /**
     * 重置 linter
     *
     * @param {string} text - 公式字串Ｆ
     */
    reset(text?: string): void;
    /**
     * 驗證公式
     *
     * @param {string} text - 公式字串
     * @returns {object} - 錯誤訊息
     */
    verify(text: string): {
        from: number;
        to: number;
        severity: string;
        message: string;
    } | null;
    /**
     * 取得錯誤訊息
     *
     * @param {ErrorMessage} error - 錯誤資訊
     * @returns {object}
     */
    private errorMsg;
    //#region 字符的驗證規則
    /**
     * 存在等待配對的引號
     *
     * @param {number} pos - 字符位置
     */
    private waitForQuote;
    /**
     * 遇到尚未配對的引號
     *
     * @param {number} pos - 字符位置
     */
    private meetQuote;
    /**
     * 遇到可配對的表單項目結尾 }
     *
     * @param {number} pos - 字符位置
     */
    private meetEndOfItem;
    /**
     * 遇到表單項目開頭 {
     *
     * @param {number} pos - 字符位置
     */
    private meetStartOfItem;
    /**
     * 存在等待配對的表單項目
     *
     * @param {number} pos - 字符位置
     */
    private waitForItemEnd;
    /**
     * 遇到等待配對的括號 )
     *
     * @param {number} pos - 字符位置
     */
    private meetRightParen;
    /**
     * 遇到尚未配對的括號 (
     *
     * @param {number} pos - 字符位置
     */
    private meetLeftParen;
    /**
     * 遇到大寫字母
     *
     * @param {number} pos - 字符位置
     */
    private meetUppercase;
    /**
     * 遇到數學符號 * | /
     *
     * @param {number} pos - 字符位置
     */
    private meetArith;
    /**
     * 遇到正負號 + | -
     *
     * @param {number} pos - 字符位置
     */
    private meetSign;
    /**
     * 遇到等於符號 =
     *
     * @param {number} pos - 字符位置
     */
    private meetEqual;
    /**
     * 遇到大於符號 >
     *
     * @param {number} pos - 字符位置
     */
    private meetGt;
    /**
     * 遇到小於符號 <
     *
     * @param {number} pos - 字符位置
     */
    private meetLt;
    /**
     * 遇到逗號 ,
     *
     * @param {number} pos - 字符位置
     */
    private meetComma;
    /**
     * 檢查是否剩下尚未配對的表單項目
     */
    private checkUnmatchedItem;
    /**
     * 檢查是否剩下尚未配對的引號
     */
    private checkUnmatchedQuote;
    /**
     * 檢查是否剩下尚未配對的括號
     */
    private checkUnmatchedParen;
}
declare const nuLint: NuLinter;
declare const nuformulaLinter: (callback: (error: Diagnostic) => void) => import("@codemirror/state").Extension;
// 語言標籤樣式
declare function nuformulaHighlightStyle(): import("@codemirror/state").Extension;
/**
 * 輸出 自動選字 掛件
 *
 * @param {Object} options - 可選選項
 * @returns {Extension}
 */
declare function nuformulaAutocomplete(formItems: {
    [key: string]: Item;
}): import("@codemirror/state").Extension;
export { NuformulaLanguage, nuformula, nuformulaItemWidget, nuLint, nuformulaLinter, nuformulaHighlightStyle, nuformulaAutocomplete, Item, isEmptyValue, funcName };
